#!/bin/sh
#OrientDB Server startup script

ORIENTDB_CONFIG_FILE="/usr/share/orientdb/bin/serverconfigured"
ORIENTDB_SERVER_CONFIG="/usr/share/orientdb/config/orientdb-server-config.xml"
export ORIENTDB_HOME="/usr/share/orientdb"

#Check whether orientdb is configured or not
if [ ! -f $ORIENTDB_CONFIG_FILE ]; then	
	touch ${ORIENTDB_CONFIG_FILE}
fi

STATUS=$(grep isAfterFirstTime $ORIENTDB_SERVER_CONFIG | cut -d"<" -f2 |cut -d">" -f2)
if [[ $STATUS != "true" ]];then
	export ORIENTDB_ROOT_PASSWORD=`base64 -di /etc/opt/novell/iprintmobile/conf/credstore.conf | grep orientdb.password  | cut -d'>' -f 2 | cut -d'<' -f 1`
fi

if [ ! -f "${CONFIG_FILE}" ]
then
    CONFIG_FILE=$ORIENTDB_HOME/config/orientdb-server-config.xml
fi

# Raspberry Pi check (Java VM does not run with -server argument on ARMv6)
if [ `uname -m` != "armv6l" ]; then
    JAVA_OPTS="$JAVA_OPTS -server "
fi
export JAVA_OPTS

# Set JavaHome if it exists
#if [ -f "${JAVA_HOME}/bin/java" ]; then 
#   JAVA=${JAVA_HOME}/bin/java
#else
#   JAVA=java
#fi
JAVA=/usr/lib64/jvm/jre-11-openjdk/bin/java
export JAVA

if [ -z "$ORIENTDB_LOG_CONF" ] ; then
    ORIENTDB_LOG_CONF=$ORIENTDB_HOME/config/orientdb-server-log.properties
fi

if [ -z "$ORIENTDB_WWW_PATH" ] ; then
    ORIENTDB_WWW_PATH=$ORIENTDB_HOME/www
fi

if [ -z "$ORIENTDB_PID" ] ; then


    ORIENTDB_PID=$ORIENTDB_HOME/bin/orient.pid
fi

if [ -f "$ORIENTDB_PID" ]; then
    echo "removing old pid file $ORIENTDB_PID"
    rm "$ORIENTDB_PID"
fi

# DEBUG OPTS, SIMPLY USE 'server.sh debug'
DEBUG_OPTS=""
ARGS='';
for var in "$@"; do
    if [ "$var" = "debug" ]; then
        DEBUG_OPTS="-Xdebug -Xrunjdwp:transport=dt_socket,server=y,suspend=n,address=1044"
    else
        ARGS="$ARGS $var"
    fi
done

# ORIENTDB memory options, max to 1GB of heap.

if [ -z "$ORIENTDB_OPTS_MEMORY" ] ; then
    ORIENTDB_OPTS_MEMORY="-Xmx1G -XX:MaxMetaspaceSize=1G"
fi

if [ -z "$JAVA_OPTS_SCRIPT" ] ; then
    JAVA_OPTS_SCRIPT="-Djna.nosys=true -XX:+HeapDumpOnOutOfMemoryError -Djava.awt.headless=true -Dfile.encoding=UTF8 -Drhino.opt.level=9"
fi

# ORIENTDB SETTINGS LIKE DISKCACHE, ETC
if [ -z "$ORIENTDB_SETTINGS" ]; then
    ORIENTDB_SETTINGS="-Denvironment.dumpCfgAtStartup=true -Dtx.useLog=false" # HERE YOU CAN PUT YOUR DEFAULT SETTINGS
fi

echo $$ > $ORIENTDB_PID

exec "$JAVA" $JAVA_OPTS \
    $ORIENTDB_OPTS_MEMORY \
    $JAVA_OPTS_SCRIPT \
    $ORIENTDB_SETTINGS \
    $DEBUG_OPTS \
    -Djava.util.logging.manager=com.orientechnologies.common.log.ShutdownLogManager \
    -Djava.util.logging.config.file="$ORIENTDB_LOG_CONF" \
    -Dorientdb.config.file="$CONFIG_FILE" \
    -Dorientdb.www.path="$ORIENTDB_WWW_PATH" \
    -Dorientdb.build.number="3.0.x@r355adf5e012545012ea2ef7682bcb95f77b0934e; 2020-03-18 15:14:21+0000" \
    -cp "$ORIENTDB_HOME/lib/orientdb-server-3.0.30.jar:$ORIENTDB_HOME/lib/*:$ORIENTDB_HOME/plugins/*" \
    $ARGS com.orientechnologies.orient.server.OServerMain
